@@ -29,7 +29,7 @@
 #include <QMenuBar>
 #include <QScreen>
 
-#include <kaboutdata.h>
+#include <KAboutData>
 #include <KMessageBox>
 #include <KConfigGroup>
 #include <KCModuleInfo>
@@ -38,7 +38,7 @@
 #include <KActionCollection>
 #include <KServiceTypeTrader>
 #include <KToolBar>
-#include <kwindowconfig.h>
+#include <KWindowConfig>
 
 #include "BaseData.h"
 #include "ModuleView.h"
@@ -309,8 +309,9 @@ void SettingsBase::configShow()
     if( activeView && activeView->moduleView() && !activeView->moduleView()->resolveChanges() ) {
         return; // It shouldn't be triggering anyway, since the action is disabled
     }
-
-    activeView->loadConfiguration();
+    if ( activeView ) {
+        activeView->loadConfiguration();
+    }
 
     const QStringList pluginList = possibleViews.keys();
     const int configIndex = pluginList.indexOf( BaseConfig::activeView() );
