@@ -41,10 +41,15 @@ class SettingsBase : public KXmlGuiWindow
     Q_OBJECT
 
 public:
-    explicit SettingsBase(QWidget * parent = nullptr);
+    explicit SettingsBase(BaseMode::ApplicationMode mode, QWidget * parent = nullptr);
     ~SettingsBase() override;
+    bool isInfoCenterMode() const;
     bool queryClose() override;
 
+    void setStartupModule(const QString &startupModule);
+    void setStartupModuleArgs(const QStringList &startupModuleArgs);
+    void reloadStartupModule();
+
 protected:
     QSize sizeHint() const override;
 
@@ -88,10 +93,14 @@ private:
     QStackedWidget * stackedWidget = nullptr;
     // The module list
     MenuItem * rootModule = nullptr;
+    MenuItem * homeModule = nullptr;
     MenuItem * lostFound = nullptr;
     KService::List categories;
     KService::List modules;
     // The about dialog
     KAboutApplicationDialog * aboutDialog = nullptr;
+    BaseMode::ApplicationMode m_mode = BaseMode::SystemSettings;
+    QString m_startupModule;
+    QStringList m_startupModuleArgs;
 };
 #endif
