@@ -30,6 +30,7 @@
 
 #include <QAction>
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KCModuleInfo>
 #include <KDescendantsProxyModel>
 #include <KStandardAction>
@@ -283,6 +284,7 @@ SidebarMode::SidebarMode( QObject *parent, const QVariantList &args )
 
 SidebarMode::~SidebarMode()
 {
+    config().sync();
     delete d;
 }
 
@@ -371,6 +373,10 @@ void SidebarMode::initEvent()
         d->moduleView->setDefaultsVisible(false);
         d->moduleView->setResetVisible(false);
     }
+
+    if (config().readEntry("HighlightNonDefaultSettings", false)) {
+        toggleDefaultsIndicatorsVisibility();
+    }
 }
 
 QAction *SidebarMode::action(const QString &name) const
@@ -666,6 +672,7 @@ void SidebarMode::toggleDefaultsIndicatorsVisibility()
             }
         }
     }
+    config().writeEntry("HighlightNonDefaultSettings", d->m_defaultsIndicatorsVisible);
 
     emit defaultsIndicatorsVisibleChanged();
 }
